@@ -212,9 +212,12 @@ class _DownloadModel(ExtendedJavaWrapper):
     def __init__(self, reader, name, language, remote_loc, validator):
         super(_DownloadModel, self).__init__("com.johnsnowlabs.nlp.pretrained." + validator + ".downloadModel", reader,
                                              name, language, remote_loc)
+
+
 class _DownloadModelDirectly(ExtendedJavaWrapper):
     def __init__(self, name, remote_loc="public/models"):
-        super(_DownloadModelDirectly, self).__init__("com.johnsnowlabs.nlp.pretrained.PythonResourceDownloader.downloadModelDirectly",name, remote_loc)
+        super(_DownloadModelDirectly, self).__init__(
+            "com.johnsnowlabs.nlp.pretrained.PythonResourceDownloader.downloadModelDirectly", name, remote_loc)
 
 
 class _DownloadPipeline(ExtendedJavaWrapper):
@@ -511,3 +514,16 @@ class _DeBertaSequenceClassifierLoader(ExtendedJavaWrapper):
         super(_DeBertaSequenceClassifierLoader, self).__init__(
             "com.johnsnowlabs.nlp.annotators.classifier.dl.DeBertaForSequenceClassification.loadSavedModel", path,
             jspark)
+
+
+class _DeBertTokenClassifierLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_DeBertTokenClassifierLoader, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.classifier.dl.DeBertaForTokenClassification.loadSavedModel", path, jspark)
+
+
+class _CamemBertLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_CamemBertLoader, self).__init__("com.johnsnowlabs.nlp.embeddings.CamemBertEmbeddings.loadSavedModel",
+                                               path,
+                                               jspark)
